==> qtjambi-nfc-5.15.20-sources.jar: io/qt/nfc/QNdefNfcUriRecord.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>NFC RTD-URI</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html">QNdefNfcUriRecord</a></code></p>
 */
public class QNdefNfcUriRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#QNdefNfcUriRecord">QNdefNfcUriRecord::<wbr/>QNdefNfcUriRecord()</a></code></p>
     */
    public QNdefNfcUriRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcUriRecord instance);
    
    /**
     * <p>See <code>QNdefNfcUriRecord::<wbr/>QNdefNfcUriRecord(QNdefNfcUriRecord)</code></p>
     */
    public QNdefNfcUriRecord(io.qt.nfc.@NonNull QNdefNfcUriRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcUriRecord instance, io.qt.nfc.QNdefNfcUriRecord other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#QNdefNfcUriRecord-1">QNdefNfcUriRecord::<wbr/>QNdefNfcUriRecord(QNdefRecord)</a></code></p>
     */
    public QNdefNfcUriRecord(io.qt.nfc.@NonNull QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcUriRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#setUri">QNdefNfcUriRecord::<wbr/>setUri(QUrl)</a></code></p>
     */
    @QtUninvokable
    public final void setUri(io.qt.core.@NonNull QUrl uri){
        setUri_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(uri));
    }
    
    @QtUninvokable
    private native void setUri_native_cref_QUrl(long __this__nativeId, long uri);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qndefnfcurirecord.html#uri">QNdefNfcUriRecord::<wbr/>uri()const</a></code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl uri(){
        return uri_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl uri_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QNdefNfcUriRecord(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Creates and returns a copy of this object.</p>
    <p>See <code>QNdefNfcUriRecord::<wbr/>QNdefNfcUriRecord(QNdefNfcUriRecord)</code></p>
     */
    @QtUninvokable
    @Override
    public QNdefNfcUriRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNdefNfcUriRecord clone_native(long __this_nativeId);
    
    /**
     * <p>Overloaded function for {@link #setUri(io.qt.core.QUrl)}.</p>
     */
    @QtUninvokable
    public final void setUri(java.lang.@NonNull String uri) {
        setUri(new io.qt.core.QUrl(uri));
    }
}

==> qtjambi-nfc-6.2.12-sources.jar: io/qt/nfc/QNdefNfcUriRecord.java <==
package io.qt.nfc;

import io.qt.*;


/**
 * <p>NFC RTD-URI</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qndefnfcurirecord.html">QNdefNfcUriRecord</a></p>
 */
public class QNdefNfcUriRecord extends io.qt.nfc.QNdefRecord
    implements java.lang.Cloneable
{
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfcurirecord.html#QNdefNfcUriRecord">QNdefNfcUriRecord::QNdefNfcUriRecord()</a></p>
     */
    public QNdefNfcUriRecord(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(QNdefNfcUriRecord instance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfcurirecord.html#QNdefNfcUriRecord-1">QNdefNfcUriRecord::QNdefNfcUriRecord(QNdefRecord)</a></p>
     */
    public QNdefNfcUriRecord(io.qt.nfc.@NonNull QNdefRecord other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QNdefNfcUriRecord instance, io.qt.nfc.QNdefRecord other);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfcurirecord.html#setUri">QNdefNfcUriRecord::setUri(QUrl)</a></p>
     */
    @QtUninvokable
    public final void setUri(io.qt.core.@NonNull QUrl uri){
        setUri_native_cref_QUrl(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(uri));
    }
    
    @QtUninvokable
    private native void setUri_native_cref_QUrl(long __this__nativeId, long uri);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qndefnfcurirecord.html#uri">QNdefNfcUriRecord::uri()const</a></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl uri(){
        return uri_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl uri_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QNdefNfcUriRecord(QPrivateConstructor p) { super(p); } 
    
    
    @QtUninvokable
    @Override
    public QNdefNfcUriRecord clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QNdefNfcUriRecord clone_native(long __this_nativeId);
}
